==================================
``psyclone.psyir.nodes.reference``
==================================

.. automodule:: psyclone.psyir.nodes.reference

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.reference


Classes
=======

- :py:class:`Reference`:
  Node representing a Reference Expression.


.. autoclass:: Reference
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Reference
      :parts: 1
